@@ -1,7 +1,7 @@
 /* srmag.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -34,7 +34,7 @@
 
 #define SRC_PANNING_REASON_CARET	1
 #define SRC_PANNING_REASON_FOCUS	2
-#define SORTED_ON_COORD(a, b, c) ( (a >= 0 && a < b) ? ( (b < c) ? TRUE:FALSE):FALSE) 
+#define SORTED_ON_COORD(a, b, c) ( (a >= 0 && a < b) ? ( (b <= c) ? TRUE:FALSE):FALSE) 
 
 typedef struct
 {
@@ -94,8 +94,10 @@ src_magnifier_send (gchar *magoutput)
 #ifdef SRMAG_DEBUG        
 	fprintf (stderr,"\nXML:%s",magoutput);
 #endif
-	mag_xml_output (magoutput, 
-			strlen (magoutput) );
+	if (g_utf8_validate (magoutput, -1, NULL))
+	    mag_xml_output (magoutput, strlen (magoutput));
+	else
+	    sru_warning ("magnifier output: invalid UTF-8 received");
     }
     busy = FALSE;
 }
@@ -678,13 +680,17 @@ src_magnifier_load_values (SRCMagnifier *magnifier)
 				       (gpointer)&default_int_val, 
 				       MAGNIFIER_CONFIG_PATH);
 
-     
+    magnifier->zp_left = MAX (0,  magnifier->zp_left);
+    magnifier->zp_right = MIN (size_x,  magnifier->zp_right);
+    magnifier->zp_top = MAX (0,  magnifier->zp_top);
+    magnifier->zp_bottom = MIN (size_y,  magnifier->zp_bottom);
+
     if (!SORTED_ON_COORD (magnifier->zp_left,
 			 magnifier->zp_right,
 			 size_x) )
     {
 	magnifier->zp_left = size_x/2;
-	magnifier->zp_right = size_x - 1;
+	magnifier->zp_right = size_x;
 	srconf_set_data (MAGNIFIER_ZP_LEFT, 
 		         CFGT_INT, 
 			 (gpointer)&magnifier->zp_left, 
@@ -700,7 +706,7 @@ src_magnifier_load_values (SRCMagnifier *magnifier)
 			 size_y) )
     {
 	magnifier->zp_top = 0;
-	magnifier->zp_bottom = size_y - 1;
+	magnifier->zp_bottom = size_y;
 	srconf_set_data (MAGNIFIER_ZP_TOP, 
 		         CFGT_INT, 
 			 (gpointer)&magnifier->zp_top, 
